==> knewstuff5-5.113.0-1-aarch64.pkg.tar.xz: usr/lib/cmake/KF5NewStuff/KF5NewStuffConfig.cmake <==
# SPDX-FileCopyrightText: KDE Contributors
# SPDX-License-Identifier: BSD-2-Clause


####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was KF5NewStuffConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/cmake/KF5NewStuff" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

include(CMakeFindDependencyMacro)
find_dependency(Qt5Widgets 5.15.2)

find_dependency(KF5XmlGui "5.113.0")
find_dependency(KF5Service "5.113.0")

find_dependency(KF5NewStuffCore "5.113.0")
find_dependency(KF5NewStuffQuick "5.113.0")

if (NOT TRUE)
    find_dependency(Qt5Qml 5.15.2)
    find_dependency(Qt5Quick 5.15.2)

    find_dependency(KF5KIO "5.113.0")
    find_dependency(KF5Completion "5.113.0")
    find_dependency(KF5I18n "5.113.0")
    find_dependency(KF5ItemViews "5.113.0")
    find_dependency(KF5IconThemes "5.113.0")
endif()

include("${CMAKE_CURRENT_LIST_DIR}/KF5NewStuffTargets.cmake")
include("${CMAKE_CURRENT_LIST_DIR}/KF5NewStuffQchTargets.cmake")

==> knewstuff-5.68.0-1-aarch64.pkg.tar.xz: usr/lib/cmake/KF5NewStuff/KF5NewStuffConfig.cmake <==

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was KF5NewStuffConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/cmake/KF5NewStuff" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

include(CMakeFindDependencyMacro)
find_dependency(Qt5Widgets 5.12.0)
find_dependency(Qt5Xml 5.12.0)

find_dependency(KF5XmlGui "5.68.0")
find_dependency(KF5Service "5.68.0")

find_dependency(KF5NewStuffCore "5.68.0")

include("${CMAKE_CURRENT_LIST_DIR}/KF5NewStuffTargets.cmake")
include("${CMAKE_CURRENT_LIST_DIR}/KF5NewStuffQchTargets.cmake")
